@@ -33,6 +33,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <iostream>
 #include <fstream>
 #include <vector>
+#include <cstdio>
 
 #include "stringtools.h"
 
@@ -68,7 +69,7 @@ ConfigurationReader::ConfigurationReader ( const string & configuration_path )
 						// if parameter already exists, make it unique
 						if ( parameterMap.count ( paramName ) )
 						{
-						    // was snprintf, but that is not in C++98
+							// snprintf ( suffix, sizeof ( suffix ), "#%05d", ++i );
 							sprintf ( suffix, "#%05d", ++i );
 							paramName+=suffix;
 						}
